@@ -1,15 +1,15 @@
 /*
  *  SPDX-FileCopyrightText: 2015 Boudhayan Gupta <bgupta@kde.org>
  *
- *  SPDX-License-Identifier: GPL-2.0-or-later
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "ExportMenu.h"
 #include "spectacle_gui_debug.h"
 
-#include <KLocalizedString>
 #include <KApplicationTrader>
 #include <KIO/ApplicationLauncherJob>
+#include <KLocalizedString>
 #include <KNotificationJobUiDelegate>
 #include <KStandardShortcut>
 #ifdef KIPI_FOUND
@@ -18,16 +18,19 @@
 
 #include <QJsonArray>
 #include <QTimer>
+#include <chrono>
 
-ExportMenu::ExportMenu(QWidget *parent) :
-    QMenu(parent),
+using namespace std::chrono_literals;
+
+ExportMenu::ExportMenu(QWidget *parent)
+    : QMenu(parent)
 #ifdef PURPOSE_FOUND
-    mUpdatedImageAvailable(false),
-    mPurposeMenu(new Purpose::Menu(this)),
+    , mUpdatedImageAvailable(false)
+    , mPurposeMenu(new Purpose::Menu(this))
 #endif
-    mExportManager(ExportManager::instance())
+    , mExportManager(ExportManager::instance())
 {
-    QTimer::singleShot(300, this, &ExportMenu::populateMenu);
+    QTimer::singleShot(300ms, this, &ExportMenu::populateMenu);
 }
 
 void ExportMenu::populateMenu()
@@ -48,7 +51,6 @@ void ExportMenu::populateMenu()
     getKServiceItems();
 }
 
-
 void ExportMenu::imageUpdated()
 {
 #ifdef PURPOSE_FOUND
@@ -58,7 +60,6 @@ void ExportMenu::imageUpdated()
 #endif
 }
 
-
 void ExportMenu::getKServiceItems()
 {
     // populate all locally installed applications and services
@@ -67,7 +68,7 @@ void ExportMenu::getKServiceItems()
     const KService::List services = KApplicationTrader::queryByMimeType(QStringLiteral("image/png"));
 
     for (auto service : services) {
-        QString name = service->name().replace(QLatin1Char('&'), QLatin1String("&&"));
+        const QString name = service->name().replace(QLatin1Char('&'), QLatin1String("&&"));
         QAction *action = new QAction(QIcon::fromTheme(service->icon()), name, this);
 
         connect(action, &QAction::triggered, this, [=]() {
@@ -97,7 +98,6 @@ void ExportMenu::getKServiceItems()
     connect(openWith, &QAction::triggered, this, [=]() {
         const QUrl filename = mExportManager->getAutosaveFilename();
         mExportManager->doSave(filename);
-        QList<QUrl> whereIs({ filename });
         auto job = new KIO::ApplicationLauncherJob;
         job->setUiDelegate(new KNotificationJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled));
         job->setUrls({filename});
@@ -120,10 +120,9 @@ void ExportMenu::getKipiItems()
     mKipiMenu->clear();
 
     mKipiInterface = new KSGKipiInterface(this);
-    
+
     KIPI::PluginLoader *loader = KIPI::PluginLoader::instance();
-    if (!loader)
-    {
+    if (!loader) {
         // The loader needs to live at least as long as the plugins
         // loaded through it, since the plugins use the loader's
         // interface() call to get the KIPI interface they conform to.
@@ -139,7 +138,7 @@ void ExportMenu::getKipiItems()
 
     KIPI::PluginLoader::PluginList pluginList = loader->pluginList();
 
-    for (const auto &pluginInfo : qAsConst(pluginList)) {
+    for (const auto &pluginInfo : std::as_const(pluginList)) {
         if (!(pluginInfo->shouldLoad())) {
             continue;
         }
@@ -164,7 +163,7 @@ void ExportMenu::getKipiItems()
             }
         }
 
-        for (auto action : qAsConst(exportActions)) {
+        for (auto action : std::as_const(exportActions)) {
             mKipiMenu->addAction(action);
         }
     }
@@ -187,9 +186,9 @@ void ExportMenu::loadPurposeMenu()
     // set up the callback signal
     connect(mPurposeMenu, &Purpose::Menu::finished, this, [this](const QJsonObject &output, int error, const QString &message) {
         if (error) {
-            emit imageShared(true, message);
+            Q_EMIT imageShared(true, message);
         } else {
-            emit imageShared(false, output[QStringLiteral("url")].toString());
+            Q_EMIT imageShared(false, output[QStringLiteral("url")].toString());
         }
     });
 
@@ -207,10 +206,8 @@ void ExportMenu::loadPurposeItems()
     QString dataUri = ExportManager::instance()->tempSave().toString();
     mUpdatedImageAvailable = false;
 
-    mPurposeMenu->model()->setInputData(QJsonObject {
-        { QStringLiteral("mimeType"), QStringLiteral("image/png") },
-        { QStringLiteral("urls"), QJsonArray({ dataUri }) }
-    });
+    mPurposeMenu->model()->setInputData(
+        QJsonObject{{QStringLiteral("mimeType"), QStringLiteral("image/png")}, {QStringLiteral("urls"), QJsonArray({dataUri})}});
     mPurposeMenu->model()->setPluginType(QStringLiteral("Export"));
     mPurposeMenu->reload();
 }
