@@ -6,24 +6,25 @@
 
 #include "KSMainWindow.h"
 
-#include "settings.h"
-#include "SettingsDialog/SettingsDialog.h"
 #include "SettingsDialog/GeneralOptionsPage.h"
 #include "SettingsDialog/SaveOptionsPage.h"
+#include "SettingsDialog/SettingsDialog.h"
 #include "SettingsDialog/ShortcutsOptionsPage.h"
+#include "settings.h"
 
 #include <QApplication>
 #include <QClipboard>
-#include <QDesktopServices>
 #include <QDBusConnection>
 #include <QDBusMessage>
+#include <QDesktopServices>
 #include <QKeyEvent>
+#include <QPainter>
 #include <QPrintDialog>
 #include <QPushButton>
 #include <QTimer>
-#include <QtMath>
-#include <QVariantAnimation>
 #include <QVBoxLayout>
+#include <QVariantAnimation>
+#include <QtMath>
 
 #ifdef XCB_FOUND
 #include <QX11Info>
@@ -31,13 +32,13 @@
 #endif
 
 #include <KAboutData>
+#include <KConfigGroup>
 #include <KGuiItem>
 #include <KHelpMenu>
+#include <KIO/JobUiDelegate>
 #include <KIO/OpenFileManagerWindowJob>
 #include <KIO/OpenUrlJob>
-#include <KIO/JobUiDelegate>
 #include <KLocalizedString>
-#include <KConfigGroup>
 #include <KSharedConfig>
 #include <KStandardAction>
 #include <KWindowSystem>
@@ -46,27 +47,30 @@ static const int DEFAULT_WINDOW_HEIGHT = 420;
 static const int DEFAULT_WINDOW_WIDTH = 840;
 static const int MAXIMUM_WINDOW_WIDTH = 1000;
 
-KSMainWindow::KSMainWindow(Platform::GrabModes theGrabModes, Platform::ShutterModes theShutterModes, QWidget *parent) :
-    QDialog(parent),
-    mKSWidget(new KSWidget(theGrabModes, this)),
-    mDivider(new QFrame(this)),
-    mDialogButtonBox(new QDialogButtonBox(this)),
-    mConfigureButton(new QToolButton(this)),
-    mToolsButton(new QPushButton(this)),
-    mSendToButton(new QPushButton(this)),
-    mClipboardButton(new QToolButton(this)),
-    mSaveButton(new QToolButton(this)),
-    mSaveMenu(new QMenu(this)),
-    mSaveAsAction(new QAction(this)),
-    mSaveAction(new QAction(this)),
-    mMessageWidget(new KMessageWidget(this)),
-    mToolsMenu(new QMenu(this)),
-    mScreenRecorderToolsMenu(new QMenu(this)),
-    mExportMenu(new ExportMenu(this)),
-    mShutterModes(theShutterModes)
+KSMainWindow::KSMainWindow(Platform::GrabModes theGrabModes, Platform::ShutterModes theShutterModes, QWidget *parent)
+    : QDialog(parent)
+    , mKSWidget(new KSWidget(theGrabModes, this))
+    , mDivider(new QFrame(this))
+    , mDialogButtonBox(new QDialogButtonBox(this))
+    , mConfigureButton(new QToolButton(this))
+    , mToolsButton(new QPushButton(this))
+    , mSendToButton(new QPushButton(this))
+    , mClipboardButton(new QToolButton(this))
+    , mClipboardMenu(new QMenu(this))
+    , mClipboardLocationAction(new QAction(this))
+    , mClipboardImageAction(new QAction(this))
+    , mSaveButton(new QToolButton(this))
+    , mSaveMenu(new QMenu(this))
+    , mSaveAsAction(new QAction(this))
+    , mSaveAction(new QAction(this))
+    , mMessageWidget(new KMessageWidget(this))
+    , mToolsMenu(new QMenu(this))
+    , mScreenRecorderToolsMenu(new QMenu(this))
+    , mExportMenu(new ExportMenu(this))
+    , mShutterModes(theShutterModes)
 #ifdef KIMAGEANNOTATOR_FOUND
-    ,mAnnotateButton(new QToolButton(this))
-    ,mAnnotatorActive(false)
+    , mAnnotateButton(new QToolButton(this))
+    , mAnnotatorActive(false)
 #endif
 {
     // before we do anything, we need to set a window property
@@ -93,13 +97,13 @@ KSMainWindow::KSMainWindow(Platform::GrabModes theGrabModes, Platform::ShutterMo
         xcb_intern_atom_cookie_t atomCookie = xcb_intern_atom_unchecked(xcbConn, false, effectName.length(), effectName.constData());
         QScopedPointer<xcb_intern_atom_reply_t, QScopedPointerPodDeleter> atom(xcb_intern_atom_reply(xcbConn, atomCookie, nullptr));
         if (atom.isNull()) {
-          goto done;
+            goto done;
         }
 
         uint32_t value = 1;
         xcb_change_property(xcbConn, XCB_PROP_MODE_REPLACE, winId(), atom->atom, XCB_ATOM_CARDINAL, 32, 1, &value);
     }
-    done:
+done:
 #endif
 
     QMetaObject::invokeMethod(this, "init", Qt::QueuedConnection);
@@ -112,9 +116,6 @@ void KSMainWindow::init()
     KSharedConfigPtr config = KSharedConfig::openConfig(QStringLiteral("spectaclerc"));
     KConfigGroup guiConfig(config, "GuiConfig");
 
-    // window properties
-    setWindowFlags(windowFlags() & ~Qt::WindowContextHelpButtonHint);
-
     QPoint location = guiConfig.readEntry("window-position", QPoint(50, 50));
     move(location);
 
@@ -122,6 +123,7 @@ void KSMainWindow::init()
 
     connect(ExportManager::instance(), &ExportManager::imageSaved, this, &KSMainWindow::imageSaved);
     connect(ExportManager::instance(), &ExportManager::imageCopied, this, &KSMainWindow::imageCopied);
+    connect(ExportManager::instance(), &ExportManager::imageLocationCopied, this, &KSMainWindow::imageSavedAndLocationCopied);
     connect(ExportManager::instance(), &ExportManager::imageSavedAndCopied, this, &KSMainWindow::imageSavedAndCopied);
 
     // the KSGWidget
@@ -146,7 +148,6 @@ void KSMainWindow::init()
     mAnnotateButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     mAnnotateButton->setIcon(QIcon::fromTheme(QStringLiteral("document-edit")));
     connect(mAnnotateButton, &QToolButton::clicked, this, [this] {
-
         if (mAnnotatorActive) {
             mKSWidget->hideAnnotator();
             mAnnotateButton->setText(i18n("Annotate"));
@@ -167,8 +168,7 @@ void KSMainWindow::init()
 #endif
 
     KGuiItem::assign(mToolsButton, KGuiItem(i18n("Tools")));
-    mToolsButton->setIcon(QIcon::fromTheme(QStringLiteral("tools"),
-                                           QIcon::fromTheme(QStringLiteral("application-menu"))));
+    mToolsButton->setIcon(QIcon::fromTheme(QStringLiteral("tools"), QIcon::fromTheme(QStringLiteral("application-menu"))));
     mToolsButton->setAutoDefault(false);
     mDialogButtonBox->addButton(mToolsButton, QDialogButtonBox::ActionRole);
     mToolsButton->setMenu(mToolsMenu);
@@ -178,9 +178,8 @@ void KSMainWindow::init()
     mSendToButton->setAutoDefault(false);
     mDialogButtonBox->addButton(mSendToButton, QDialogButtonBox::ActionRole);
 
-    mClipboardButton->setDefaultAction(KStandardAction::copy(this, &KSMainWindow::copy, this));
-    mClipboardButton->setText(i18n("Copy to Clipboard"));
-    mClipboardButton->setToolTip(i18n("Copy the current screenshot image to the clipboard."));
+    mClipboardButton->setMenu(mClipboardMenu);
+    mClipboardButton->setPopupMode(QToolButton::MenuButtonPopup);
     mClipboardButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     mDialogButtonBox->addButton(mClipboardButton, QDialogButtonBox::ActionRole);
 
@@ -196,18 +195,18 @@ void KSMainWindow::init()
     // the tools menu
     mToolsMenu->addAction(QIcon::fromTheme(QStringLiteral("document-open-folder")),
                           i18n("Open Default Screenshots Folder"),
-                          this, &KSMainWindow::openScreenshotsFolder);
+                          this,
+                          &KSMainWindow::openScreenshotsFolder);
     mToolsMenu->addAction(KStandardAction::print(this, &KSMainWindow::showPrintDialog, this));
     mScreenRecorderToolsMenu = mToolsMenu->addMenu(i18n("Record Screen"));
     mScreenRecorderToolsMenu->setIcon(QIcon::fromTheme(QStringLiteral("media-record")));
-    connect(mScreenRecorderToolsMenu, &QMenu::aboutToShow, this, [this]()
-    {
+    connect(mScreenRecorderToolsMenu, &QMenu::aboutToShow, this, [this]() {
         KMoreToolsMenuFactory *moreToolsMenuFactory = new KMoreToolsMenuFactory(QStringLiteral("spectacle/screenrecorder-tools"));
         moreToolsMenuFactory->setParentWidget(this);
         mScreenrecorderToolsMenuFactory.reset(moreToolsMenuFactory);
         mScreenRecorderToolsMenu->clear();
-        mScreenrecorderToolsMenuFactory->fillMenuFromGroupingNames(mScreenRecorderToolsMenu, { QStringLiteral("screenrecorder") });
-    } );
+        mScreenrecorderToolsMenuFactory->fillMenuFromGroupingNames(mScreenRecorderToolsMenu, {QStringLiteral("screenrecorder")});
+    });
 
     // the save menu
     mSaveAsAction = KStandardAction::saveAs(this, &KSMainWindow::saveAs, this);
@@ -216,8 +215,19 @@ void KSMainWindow::init()
     mSaveMenu->addAction(mSaveAction);
     setDefaultSaveAction();
 
+    // the clipboard menu
+    mClipboardImageAction = KStandardAction::copy(this, &KSMainWindow::copyImage, this);
+    mClipboardImageAction->setText(i18n("Copy Image to Clipboard"));
+    mClipboardLocationAction = new QAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy Location to Clipboard"), this);
+    connect(mClipboardLocationAction, &QAction::triggered, this, &KSMainWindow::copyLocation);
+    mClipboardMenu->addAction(mClipboardImageAction);
+    mClipboardMenu->addAction(mClipboardLocationAction);
+    setDefaultCopyAction();
+
     // message widget
-    connect(mMessageWidget, &KMessageWidget::linkActivated, this, [](const QString &str) { QDesktopServices::openUrl(QUrl(str)); } );
+    connect(mMessageWidget, &KMessageWidget::linkActivated, this, [](const QString &str) {
+        QDesktopServices::openUrl(QUrl(str));
+    });
 
     // layouts
     mDivider->setFrameShape(QFrame::HLine);
@@ -240,7 +250,6 @@ void KSMainWindow::init()
     } else if (!mShutterModes.testFlag(Platform::ShutterMode::Immediate)) {
         mKSWidget->lockOnClickEnabled();
     }
-    resize(QSize(DEFAULT_WINDOW_WIDTH, DEFAULT_WINDOW_HEIGHT).expandedTo(minimumSize()));
 
     // Allow Ctrl+Q to quit the app
     QAction *actionQuit = KStandardAction::quit(qApp, &QApplication::quit, this);
@@ -249,15 +258,29 @@ void KSMainWindow::init()
 
     // message: open containing folder
     mOpenContaining = new QAction(QIcon::fromTheme(QStringLiteral("document-open-folder")), i18n("Open Containing Folder"), mMessageWidget);
-    connect(mOpenContaining, &QAction::triggered, [=] { KIO::highlightInFileManager({Settings::lastSaveLocation()});});
+    connect(mOpenContaining, &QAction::triggered, [=] {
+        QUrl imageUrl;
+        if (ExportManager::instance()->isImageSavedNotInTemp()) {
+            imageUrl = Settings::lastSaveLocation();
+        } else {
+            imageUrl = ExportManager::instance()->tempSave();
+        }
+
+        KIO::highlightInFileManager({imageUrl});
+    });
 
     mHideMessageWidgetTimer = new QTimer(this);
-//     connect(mHideMessageWidgetTimer, &QTimer::timeout,
-//             mMessageWidget, &KMessageWidget::animatedHide);
+    //     connect(mHideMessageWidgetTimer, &QTimer::timeout,
+    //             mMessageWidget, &KMessageWidget::animatedHide);
     mHideMessageWidgetTimer->setInterval(10000);
     // done with the init
 }
 
+QSize KSMainWindow::sizeHint() const
+{
+    return QSize(DEFAULT_WINDOW_WIDTH, DEFAULT_WINDOW_HEIGHT).expandedTo(minimumSize());
+}
+
 int KSMainWindow::windowWidth(const QPixmap &pixmap) const
 {
     // Calculates what the width of the window should be for the captured image to perfectly fit
@@ -286,6 +309,20 @@ void KSMainWindow::setDefaultSaveAction()
     }
 }
 
+void KSMainWindow::setDefaultCopyAction()
+{
+    switch (Settings::lastUsedCopyMode()) {
+    case Settings::CopyImage:
+        mClipboardButton->setText(i18n("Copy Image to Clipboard"));
+        mClipboardButton->setDefaultAction(mClipboardImageAction);
+        break;
+    case Settings::CopyLocation:
+        mClipboardButton->setText(i18n("Copy Location to Clipboard"));
+        mClipboardButton->setDefaultAction(mClipboardLocationAction);
+        break;
+    }
+}
+
 // overrides
 
 void KSMainWindow::moveEvent(QMoveEvent *event)
@@ -304,18 +341,18 @@ void KSMainWindow::captureScreenshot(Spectacle::CaptureMode theCaptureMode, int
 {
     if (theTimeout < 0) { // OnClick is checked (always the case on Wayland)
         hide();
-        emit newScreenshotRequest(theCaptureMode, theTimeout, theIncludePointer, theIncludeDecorations);
+        Q_EMIT newScreenshotRequest(theCaptureMode, theTimeout, theIncludePointer, theIncludeDecorations);
         return;
     }
 
     showMinimized();
     mMessageWidget->hide();
-    QTimer* timer = new QTimer;
+    QTimer *timer = new QTimer;
     timer->setSingleShot(true);
     timer->setInterval(theTimeout);
     auto unityUpdate = [](const QVariantMap &properties) {
-        QDBusMessage message = QDBusMessage::createSignal(QStringLiteral("/org/kde/Spectacle"),
-            QStringLiteral("com.canonical.Unity.LauncherEntry"), QStringLiteral("Update"));
+        QDBusMessage message =
+            QDBusMessage::createSignal(QStringLiteral("/org/kde/Spectacle"), QStringLiteral("com.canonical.Unity.LauncherEntry"), QStringLiteral("Update"));
         message.setArguments({QGuiApplication::desktopFileName(), properties});
         QDBusConnection::sessionBus().send(message);
     };
@@ -327,28 +364,25 @@ void KSMainWindow::captureScreenshot(Spectacle::CaptureMode theCaptureMode, int
         const double progress = delayAnimation->currentValue().toDouble();
         const double timeoutInSeconds = theTimeout / 1000.0;
         mKSWidget->setProgress(progress);
-        unityUpdate({ {QStringLiteral("progress"), progress} });
-        setWindowTitle(i18ncp("@title:window", "%1 second", "%1 seconds",
-            qMin(int(timeoutInSeconds), qCeil((1 - progress) * timeoutInSeconds))));
+        unityUpdate({{QStringLiteral("progress"), progress}});
+        setWindowTitle(i18ncp("@title:window", "%1 second", "%1 seconds", qMin(int(timeoutInSeconds), qCeil((1 - progress) * timeoutInSeconds))));
     });
     connect(timer, &QTimer::timeout, this, [=] {
         this->hide();
         timer->deleteLater();
         mKSWidget->setProgress(0);
-        unityUpdate({ {QStringLiteral("progress-visible"), false} });
-        emit newScreenshotRequest(theCaptureMode, 0, theIncludePointer, theIncludeDecorations);
+        unityUpdate({{QStringLiteral("progress-visible"), false}});
+        Q_EMIT newScreenshotRequest(theCaptureMode, 0, theIncludePointer, theIncludeDecorations);
     });
 
     connect(mKSWidget, &KSWidget::screenshotCanceled, timer, [=] {
         timer->stop();
         timer->deleteLater();
         restoreWindowTitle();
-        unityUpdate({ {QStringLiteral("progress-visible"), false} });
+        unityUpdate({{QStringLiteral("progress-visible"), false}});
     });
 
-
-    unityUpdate({   {QStringLiteral("progress-visible"), true},
-                    {QStringLiteral("progress"), 0 } });
+    unityUpdate({{QStringLiteral("progress-visible"), true}, {QStringLiteral("progress"), 0}});
     timer->start();
     delayAnimation->start();
 }
@@ -368,7 +402,7 @@ void KSMainWindow::setScreenshotAndShow(const QPixmap &pixmap)
     activateWindow();
     /* NOTE windowWidth only produces the right result if it is called after the window is visible.
      * Because of this the call is not moved into the if above */
-    if(!pixmap.isNull()) {
+    if (!pixmap.isNull()) {
         resize(QSize(windowWidth(pixmap), DEFAULT_WINDOW_HEIGHT));
     }
 }
@@ -403,14 +437,16 @@ void KSMainWindow::quit(const QuitBehavior quitBehavior)
     }
 }
 
-void KSMainWindow::showInlineMessage(const QString& message, const KMessageWidget::MessageType messageType,
-                                     const MessageDuration messageDuration, const QList<QAction*>& actions)
+void KSMainWindow::showInlineMessage(const QString &message,
+                                     const KMessageWidget::MessageType messageType,
+                                     const MessageDuration messageDuration,
+                                     const QList<QAction *> &actions)
 {
     const auto messageWidgetActions = mMessageWidget->actions();
-    for (QAction* action: messageWidgetActions) {
+    for (QAction *action : messageWidgetActions) {
         mMessageWidget->removeAction(action);
     }
-    for (QAction* action : actions) {
+    for (QAction *action : actions) {
         mMessageWidget->addAction(action);
     }
     mMessageWidget->setText(message);
@@ -446,21 +482,36 @@ void KSMainWindow::showImageSharedFeedback(bool error, const QString &message)
     }
 
     if (error) {
-        showInlineMessage(i18n("There was a problem sharing the image: %1", message),
-                          KMessageWidget::Error);
+        showInlineMessage(i18n("There was a problem sharing the image: %1", message), KMessageWidget::Error);
     } else {
         if (message.isEmpty()) {
             showInlineMessage(i18n("Image shared"), KMessageWidget::Positive);
         } else {
             showInlineMessage(i18n("The shared image link (<a href=\"%1\">%1</a>) has been copied to the clipboard.", message),
-                              KMessageWidget::Positive, MessageDuration::Persistent);
+                              KMessageWidget::Positive,
+                              MessageDuration::Persistent);
             QApplication::clipboard()->setText(message);
         }
     }
 }
 
-void KSMainWindow::copy()
+void KSMainWindow::copyLocation()
 {
+    Settings::setLastUsedCopyMode(Settings::CopyLocation);
+    setDefaultCopyAction();
+
+    const bool quitChecked = Settings::quitAfterSaveCopyExport();
+    ExportManager::instance()->doCopyLocationToClipboard();
+    if (quitChecked) {
+        quit(QuitBehavior::QuitExternally);
+    }
+}
+
+void KSMainWindow::copyImage()
+{
+    Settings::setLastUsedCopyMode(Settings::CopyImage);
+    setDefaultCopyAction();
+
     const bool quitChecked = Settings::quitAfterSaveCopyExport();
     ExportManager::instance()->doCopyToClipboard();
     if (quitChecked) {
@@ -470,16 +521,32 @@ void KSMainWindow::copy()
 
 void KSMainWindow::imageCopied()
 {
-    showInlineMessage(i18n("The screenshot has been copied to the clipboard."),
-                      KMessageWidget::Information);
+    showInlineMessage(i18n("The screenshot has been copied to the clipboard."), KMessageWidget::Information);
+}
+
+void KSMainWindow::imageSavedAndLocationCopied(const QUrl &location)
+{
+    showInlineMessage(
+        i18n("The screenshot has been saved as <a href=\"%1\">%2</a> and its location has been copied to clipboard", location.toString(), location.fileName()),
+        KMessageWidget::Positive,
+        MessageDuration::AutoHide,
+        {mOpenContaining});
 }
 
 void KSMainWindow::screenshotFailed()
 {
-    showInlineMessage(i18n("Could not take a screenshot. Please report this bug here: <a href=\"https://bugs.kde.org/enter_bug.cgi?product=Spectacle\">create a spectacle bug</a>"),
+    showInlineMessage(i18n("Could not take a screenshot. Please report this bug here: <a href=\"https://bugs.kde.org/enter_bug.cgi?product=Spectacle\">create "
+                           "a spectacle bug</a>"),
                       KMessageWidget::Warning);
 }
 
+void KSMainWindow::setPlaceholderTextOnLaunch()
+{
+    QString placeholderText(i18n("Ready to take a screenshot"));
+    mKSWidget->showPlaceholderText(placeholderText);
+    setWindowTitle(placeholderText);
+}
+
 void KSMainWindow::showPreferencesDialog()
 {
     if (KConfigDialog::showDialog(QStringLiteral("settings"))) {
@@ -492,18 +559,20 @@ void KSMainWindow::imageSaved(const QUrl &location)
 {
     setWindowTitle(location.fileName());
     setWindowModified(false);
-    showInlineMessage(i18n("The screenshot was saved as <a href=\"%1\">%2</a>",
-                           location.toString(), location.fileName()), KMessageWidget::Positive,
-                           MessageDuration::AutoHide, {mOpenContaining});
+    showInlineMessage(i18n("The screenshot was saved as <a href=\"%1\">%2</a>", location.toString(), location.fileName()),
+                      KMessageWidget::Positive,
+                      MessageDuration::AutoHide,
+                      {mOpenContaining});
 }
 
 void KSMainWindow::imageSavedAndCopied(const QUrl &location)
 {
     setWindowTitle(location.fileName());
     setWindowModified(false);
-    showInlineMessage(i18n("The screenshot was copied to the clipboard and saved as <a href=\"%1\">%2</a>",
-                           location.toString(), location.fileName()), KMessageWidget::Positive,
-                           MessageDuration::AutoHide, {mOpenContaining});
+    showInlineMessage(i18n("The screenshot was copied to the clipboard and saved as <a href=\"%1\">%2</a>", location.toString(), location.fileName()),
+                      KMessageWidget::Positive,
+                      MessageDuration::AutoHide,
+                      {mOpenContaining});
 }
 
 void KSMainWindow::save()
@@ -534,22 +603,28 @@ void KSMainWindow::restoreWindowTitle()
     if (isWindowModified()) {
         setWindowTitle(i18nc("@title:window Unsaved Screenshot", "Unsaved[*]"));
     } else {
-        setWindowTitle(Settings::lastSaveLocation().fileName());
+        // if a screenshot is not visible inside of mKSWidget, it means we have launched spectacle
+        // with the last mode set to 'rectangular region' and canceled the screenshot
+        if (mKSWidget->isScreenshotSet()) {
+            setWindowTitle(Settings::lastSaveLocation().fileName());
+        } else {
+            setPlaceholderTextOnLaunch();
+        }
     }
 }
 
 /* This event handler enables all Buttons to be activated with Enter. Normally only QPushButton can
  * be activated with Enter but we also use QToolButtons so we handle the event ourselves */
-void KSMainWindow::keyPressEvent(QKeyEvent* event)
+void KSMainWindow::keyPressEvent(QKeyEvent *event)
 {
     if (event->key() == Qt::Key_Return) {
         QWidget *fw = focusWidget();
-        auto pb = qobject_cast<QPushButton*>(fw);
+        auto pb = qobject_cast<QPushButton *>(fw);
         if (pb) {
             pb->animateClick();
             return;
         }
-        auto tb = qobject_cast<QToolButton*>(fw);
+        auto tb = qobject_cast<QToolButton *>(fw);
         if (tb) {
             tb->animateClick();
             return;
